@@ -1,4 +1,4 @@
-#' Generalized Method of Wavelet Moments (GMWM) for IMUs, ARMA, SSM, and Robust
+#' Generalized Method of Wavelet Moments (GMWM)
 #'
 #' Performs estimation of time series models by using the GMWM estimator.
 #' @param model      A \code{ts.model} object containing one of the allowed models.
@@ -32,35 +32,35 @@
 #'                   default, this is set to 1 and only is important if \code{GM()}
 #'                   is in the model
 #' @return A \code{gmwm} object with the structure:
-#' \describe{
-#'  \item{estimate}{Estimated Parameters Values from the GMWM Procedure}
-#'  \item{init.guess}{Initial Starting Values given to the Optimization Algorithm}
-#'  \item{wv.empir}{The data's empirical wavelet variance}
-#'  \item{ci.low}{Lower Confidence Interval}
-#'  \item{ci.high}{Upper Confidence Interval}
-#'  \item{orgV}{Original V matrix}
-#'  \item{V}{Updated V matrix (if bootstrapped)}
-#'  \item{omega}{The V matrix inversed}
-#'  \item{obj.fun}{Value of the objective function at Estimated Parameter Values}
-#'  \item{theo}{Summed Theoretical Wavelet Variance}
-#'  \item{decomp.theo}{Decomposed Theoretical Wavelet Variance by Process}
-#'  \item{scales}{Scales of the GMWM Object}
-#'  \item{robust}{Indicates if parameter estimation was done under robust or classical}
-#'  \item{eff}{Level of efficiency of robust estimation}
-#'  \item{model.type}{Models being guessed}
-#'  \item{compute.v}{Type of V matrix computation}
-#'  \item{augmented}{Indicates moments have been augmented}
-#'  \item{alpha}{Alpha level used to generate confidence intervals}
-#'  \item{expect.diff}{Mean of the First Difference of the Signal}
-#'  \item{N}{Length of the Signal}
-#'  \item{G}{Number of Guesses Performed}
-#'  \item{H}{Number of Bootstrap replications}
-#'  \item{K}{Number of V matrix bootstraps}
-#'  \item{model}{\code{ts.model} supplied to gmwm}
-#'  \item{model.hat}{A new value of \code{ts.model} object supplied to gmwm}
-#'  \item{starting}{Indicates whether the procedure used the initial guessing approach}
-#'  \item{seed}{Randomization seed used to generate the guessing values}
-#'  \item{freq}{Frequency of data}
+#' \itemize{
+#'  \item estimate: Estimated Parameters Values from the GMWM Procedure
+#'  \item init.guess: Initial Starting Values given to the Optimization Algorithm
+#'  \item wv.empir: The data's empirical wavelet variance
+#'  \item ci_low: Lower Confidence Interval
+#'  \item ci_high: Upper Confidence Interval
+#'  \item orgV: Original V matrix
+#'  \item V: Updated V matrix (if bootstrapped)
+#'  \item omega: The V matrix inversed
+#'  \item obj.fun: Value of the objective function at Estimated Parameter Values
+#'  \item theo: Summed Theoretical Wavelet Variance
+#'  \item decomp.theo: Decomposed Theoretical Wavelet Variance by Process
+#'  \item scales: Scales of the GMWM Object
+#'  \item robust: Indicates if parameter estimation was done under robust or classical
+#'  \item eff: Level of efficiency of robust estimation
+#'  \item model.type: Models being guessed
+#'  \item compute.v: Type of V matrix computation
+#'  \item augmented: Indicates moments have been augmented
+#'  \item alpha: Alpha level used to generate confidence intervals
+#'  \item expect.diff: Mean of the First Difference of the Signal
+#'  \item N: Length of the Signal
+#'  \item G: Number of Guesses Performed
+#'  \item H: Number of Bootstrap replications
+#'  \item K: Number of V matrix bootstraps
+#'  \item model: \code{ts.model} supplied to gmwm
+#'  \item model.hat: A new value of \code{ts.model} object supplied to gmwm
+#'  \item starting: Indicates whether the procedure used the initial guessing approach
+#'  \item seed: Randomization seed used to generate the guessing values
+#'  \item freq: Frequency of data
 #' }
 #' @export
 #' @details
@@ -91,18 +91,18 @@
 #' The function estimates a variety of time series models. If type = "imu" or "ssm", then
 #' parameter vector should indicate the characters of the models that compose the latent or state-space model. The model
 #' options are:
-#' \describe{
-#'   \item{"AR1"}{a first order autoregressive process with parameters \eqn{(\phi,\sigma^2)}{phi, sigma^2}}
-#'   \item{"GM"}{a guass-markov process \eqn{(\beta,\sigma_{gm}^2)}{beta, sigma[gm]^2}}
-#'   \item{"ARMA"}{an autoregressive moving average process with parameters \eqn{(\phi _p, \theta _q, \sigma^2)}{phi[p], theta[q], sigma^2}}
-#'   \item{"DR"}{a drift with parameter \eqn{\omega}{omega}}
-#'   \item{"QN"}{a quantization noise process with parameter \eqn{Q}}
-#'   \item{"RW"}{a random walk process with parameter \eqn{\sigma^2}{sigma^2}}
-#'   \item{"WN"}{a white noise process with parameter \eqn{\sigma^2}{sigma^2}}
+#' \itemize{
+#'   \item "AR1": a first order autoregressive process with parameters \eqn{(\phi,\sigma^2)}{phi, sigma^2}
+#'   \item "GM": a guass-markov process \eqn{(\beta,\sigma_{gm}^2)}{beta, sigma[gm]^2}
+#'   \item "ARMA": an autoregressive moving average process with parameters \eqn{(\phi _p, \theta _q, \sigma^2)}{phi[p], theta[q], sigma^2}
+#'   \item "DR": a drift with parameter \eqn{\omega}{omega}
+#'   \item "QN": a quantization noise process with parameter \eqn{Q}
+#'   \item "RW": a random walk process with parameter \eqn{\sigma^2}{sigma^2}
+#'   \item "WN": a white noise process with parameter \eqn{\sigma^2}{sigma^2}
 #' }
 #' If only an ARMA() term is supplied, then the function takes conditional least squares as starting values
 #' If robust = TRUE the function takes the robust estimate of the wavelet variance to be used in the GMWM estimation procedure.
-gmwm = function(model, data, model.type="ssm", compute.v="auto",
+gmwm = function(model, data, model.type="imu", compute.v="auto",
                 robust=FALSE, eff=0.6, alpha = 0.05, seed = 1337, G = NULL, K = 1, H = 100,
                 freq = 1){
 
@@ -246,8 +246,8 @@ gmwm = function(model, data, model.type="ssm", compute.v="auto",
   out = structure(list(estimate = estimate,
                        init.guess = init.guess,
                        wv.empir = out[[3]],
-                       ci.low = out[[4]],
-                       ci.high = out[[5]],
+                       ci_low = out[[4]],
+                       ci_high = out[[5]],
                        orgV = out[[7]],
                        V = out[[6]],
                        omega = out[[12]],
@@ -282,12 +282,12 @@ gmwm = function(model, data, model.type="ssm", compute.v="auto",
 #' @param model   A \code{ts.model} object containing one of the allowed models
 #' @param ...     Additional parameters (not used)
 #' @return A \code{gmwm} object with the structure:
-#' \describe{
+#' \itemize{
 #'  \item{estimate}{Estimated Parameters Values from the GMWM Procedure}
 #'  \item{init.guess}{Initial Starting Values given to the Optimization Algorithm}
 #'  \item{wv.empir}{The data's empirical wavelet variance}
-#'  \item{ci.low}{Lower Confidence Interval}
-#'  \item{ci.high}{Upper Confidence Interval}
+#'  \item{ci_low}{Lower Confidence Interval}
+#'  \item{ci_high}{Upper Confidence Interval}
 #'  \item{orgV}{Original V matrix}
 #'  \item{V}{Updated V matrix (if bootstrapped)}
 #'  \item{omega}{The V matrix inversed}
@@ -370,7 +370,7 @@ update.gmwm = function(object, model, ...){
   out = gmwm_update_cpp(model$theta,
               desc, obj,
               object$model.type, object$N, object$expect.diff, object$dr.slope,
-              object$orgV, object$scales, cbind(object$wv.empir,object$ci.low,object$ci.high), # needed WV info
+              object$orgV, object$scales, cbind(object$wv.empir,object$ci_low,object$ci_high), # needed WV info
               model$starting,
               object$compute.v, object$K, object$H,
               object$G,
@@ -428,12 +428,12 @@ update.gmwm = function(object, model, ...){
 #' ability to interpret with respect to \code{freq}, then use
 #' \code{AR1} terms.
 #' @return A \code{gmwm} object with the structure:
-#' \describe{
+#' \itemize{
 #'  \item{estimate}{Estimated Parameters Values from the GMWM Procedure}
 #'  \item{init.guess}{Initial Starting Values given to the Optimization Algorithm}
 #'  \item{wv.empir}{The data's empirical wavelet variance}
-#'  \item{ci.low}{Lower Confidence Interval}
-#'  \item{ci.high}{Upper Confidence Interval}
+#'  \item{ci_low}{Lower Confidence Interval}
+#'  \item{ci_high}{Upper Confidence Interval}
 #'  \item{orgV}{Original V matrix}
 #'  \item{V}{Updated V matrix (if bootstrapped)}
 #'  \item{omega}{The V matrix inversed}
@@ -537,7 +537,7 @@ print.gmwm = function(x, ...){
 #' @param B            An \code{int} that indicates how many bootstraps should be performed.
 #' @param ...          Other arguments passed to specific methods
 #' @return A \code{summary.gmwm} object with:
-#' \describe{
+#' \itemize{
 #'  \item{estimate}{Estimated Theta Values}
 #'  \item{testinfo}{Goodness of Fit Information}
 #'  \item{inference}{Inference performed? T/F}
@@ -700,7 +700,7 @@ print.summary.gmwm = function(x, ...){
 #' @param n.ahead      Number of observations to forecast
 #' @param ...          Additional parameters passed to ARIMA Predict
 #' @return A \code{predict.gmwm} object with:
-#' \describe{
+#' \itemize{
 #' \item{pred}{Predictions}
 #' \item{se}{Standard Errors}
 #' \item{resid}{Residuals from ARIMA ML Fit}
@@ -743,3 +743,239 @@ predict.gmwm = function(object, data.in.gmwm, n.ahead = 1, ...){
             class = "predict.gmwm")
 
 }
+
+#' @title Plot the GMWM with the Wavelet Variance
+#'
+#' @description
+#' Displays a plot of the Wavelet Variance (WV) with the CI values and the WV implied by the estimated parameters.
+#' @method plot gmwm
+#' @param x                A \code{gmwm} object.
+#' @param decomp           A \code{boolean} that determines whether the contributions of each individual model are plotted.
+#' @param units            A \code{string} that specifies the units of time plotted on the x axis.
+#' @param xlab             A \code{string} that gives a title for the x axis.
+#' @param ylab             A \code{string} that gives a title for the y axis.
+#' @param main             A \code{string} that gives an overall title for the plot.
+#' @param col_wv           A \code{string} that specifies the color of the wavelet variance line.
+#' @param col_ci           A \code{string} that specifies the color of the shaded area covered by the confidence intervals.
+#' @param nb_ticks_x       An \code{integer} that specifies the maximum number of ticks for the x-axis.
+#' @param nb_ticks_y       An \code{integer} that specifies the maximum number of ticks for the y-axis.
+#' @param legend_position  A \code{string} that specifies the position of the legend (use \code{legend_position = NA} to remove legend).
+#' @param ci_wv            A \code{boolean} that determines whether to plot the confidence interval shaded area.
+#' @param point_cex        A \code{double} that specifies the size of each symbol to be plotted.
+#' @param point_pch        A \code{double} that specifies the symbol type to be plotted.
+#' @param ...              Additional arguments affecting the plot.
+#' @return Plot of WV and relative confidence intervals for each scale.
+#' @author Stephane Guerrier and Yuming Zhang 
+#' @export
+plot.gmwm = function(x, decomp = FALSE, units = NULL, xlab = NULL, ylab = NULL, main = NULL, 
+                     col_wv = NULL, col_ci = NULL, nb_ticks_x = NULL, nb_ticks_y = NULL,
+                     legend_position = NULL, ci_wv = NULL, point_cex = NULL, 
+                     point_pch = NULL, ...){
+  
+  # Labels
+  if (is.null(xlab)){
+    if (is.null(units)){
+      xlab = expression(paste("Scale ", tau, sep =""))
+    }else{
+      xlab = bquote(paste("Scale ", tau, " [", .(units), "]", sep = " "))
+    }
+  }
+  
+  if (is.null(ylab)){
+    ylab = expression(paste("Wavelet Variance ", nu^2, sep = ""))
+  }else{
+    ylab = ylab
+  }
+  
+  # Main Title
+  if (is.null(main)){
+    main = "Haar Wavelet Variance Representation"
+  }
+  
+  # Line and CI colors
+  if (is.null(col_wv)){
+    col_wv = "darkblue"
+  }
+  
+  if (is.null(col_ci)){
+    col_ci = hcl(h = 210, l = 65, c = 100, alpha = 0.15)
+  }
+  
+  # Range
+  x_range = range(x$scales)
+  x_low = floor(log10(x_range[1]))
+  x_high = ceiling(log10(x_range[2]))
+  
+  y_range = range(c(x$ci_low, x$ci_high))
+  y_low = floor(log10(y_range[1]))
+  y_high = ceiling(log10(y_range[2]))
+  
+  # Axes
+  if (is.null(nb_ticks_x)){
+    nb_ticks_x = 6
+  }
+  
+  if (is.null(nb_ticks_y)){
+    nb_ticks_y = 5
+  }
+  
+  x_ticks = seq(x_low, x_high, by = 1)
+  if (length(x_ticks) > nb_ticks_x){
+    x_ticks = x_low + ceiling((x_high - x_low)/(nb_ticks_x + 1))*(0:nb_ticks_x)
+  }
+  x_labels = sapply(x_ticks, function(i) as.expression(bquote(10^ .(i))))
+  
+  y_ticks <- seq(y_low, y_high, by = 1)
+  if (length(y_ticks) > nb_ticks_y){
+    y_ticks = y_low + ceiling((y_high - y_low)/(nb_ticks_y + 1))*(0:nb_ticks_y)
+  }
+  y_labels <- sapply(y_ticks, function(i) as.expression(bquote(10^ .(i))))
+  
+  # Legend Position
+  if (is.null(legend_position)){
+    # if (which.min(abs(c(y_low, y_high) - log2(x$wv.empir[1]))) == 1){
+    #   legend_position = "topleft"
+    # }else{
+    #   legend_position = "bottomleft"
+    # }
+    legend_position = "bottomleft"
+  }   
+  
+  # Main Plot                     
+  plot(NA, xlim = x_range, ylim = y_range, xlab = xlab, ylab = ylab, 
+       log = "xy", xaxt = 'n', yaxt = 'n', bty = "n", ann = FALSE)
+  win_dim = par("usr")
+  
+  par(new = TRUE)
+  plot(NA, xlim = x_range, ylim = 10^c(win_dim[3], win_dim[4] + 0.22*(win_dim[4] - win_dim[3])),
+       xlab = xlab, ylab = ylab, log = "xy", xaxt = 'n', yaxt = 'n', bty = "n")
+  win_dim = par("usr")
+  
+  # Add Grid
+  abline(v = 10^x_ticks, lty = 1, col = "grey95")
+  abline(h = 10^y_ticks, lty = 1, col = "grey95")
+  
+  # Add Title
+  x_vec = 10^c(win_dim[1], win_dim[2], win_dim[2], win_dim[1])
+  y_vec = 10^c(win_dim[4], win_dim[4],
+               win_dim[4] - 0.09*(win_dim[4] - win_dim[3]), 
+               win_dim[4] - 0.09*(win_dim[4] - win_dim[3]))
+  polygon(x_vec, y_vec, col = "grey95", border = NA)
+  text(x = 10^mean(c(win_dim[1], win_dim[2])), y = 10^(win_dim[4] - 0.09/2*(win_dim[4] - win_dim[3])), main)
+  
+  # Add Axes and Box
+  lines(x_vec[1:2], rep(10^(win_dim[4] - 0.09*(win_dim[4] - win_dim[3])),2), col = 1)
+  #y_ticks = y_ticks[(2^y_ticks) < 10^(win_dim[4] - 0.09*(win_dim[4] - win_dim[3]))]
+  y_labels = y_labels[1:length(y_ticks)]
+  box()
+  axis(1, at = 10^x_ticks, labels = x_labels, padj = 0.3)
+  axis(2, at = 10^y_ticks, labels = y_labels, padj = -0.2)  
+  
+  # CI for WV
+  if (ci_wv == TRUE || is.null(ci_wv)){
+    polygon(c(x$scales, rev(x$scales)), c(x$ci_low, rev(x$ci_high)),
+            border = NA, col = col_ci)
+  }
+  
+  # Add legend
+  CI_conf = 1 - x$alpha
+  
+  if (x$robust == TRUE){
+    wv_title_part1 = "Empirical Robust WV "
+  }else{
+    wv_title_part1 = "Empirical WV "
+  }
+  
+  # Add WV
+  lines(x$scales, x$wv.empir, type = "l", col = col_wv, pch = 16)
+  
+  if (is.null(point_pch)){
+    point_pch = 16
+  }
+  
+  if (is.null(point_cex)){
+    point_cex = 1.25
+  }
+  lines(x$scales, x$wv.empir, type = "p", col = col_wv, pch = point_pch, cex = point_cex)
+  
+  # Add model based WV
+  if (decomp == TRUE){
+    processes_theo = x$decomp.theo
+    m = ncol(processes_theo)
+    col_decomp = hcl(h = seq(100, 375, length = m + 1), l = 65, c = 200, alpha = 1)[1:m]
+    for (i in 1:m){
+      lines(x$scales, processes_theo[,i], col = col_decomp[i])
+    }
+  }
+  col_fit = "#F47F24"
+  lines(x$scales,x$theo, type = "b", lwd = 2, col = col_fit, pch = 1, cex = 1.5)
+  
+  
+  if (!is.na(legend_position)){
+    if (legend_position == "topleft"){
+      legend_position = 10^c(1.1*win_dim[1], 0.98*(win_dim[4] - 0.09*(win_dim[4] - win_dim[3])))
+      
+      if (decomp == TRUE){
+        legend(x = legend_position[1], y = legend_position[2],
+               legend = c(as.expression(bquote(paste(.(wv_title_part1), hat(nu)^2))),
+                          as.expression(bquote(paste("CI(",hat(nu)^2,", ",.(CI_conf),")"))),
+                          x$model$desc, "Model-based WV"),
+               pch = c(16, 15, rep(NA, m), 1), 
+               lty = c(1, NA, rep(1, m), 1), 
+               col = c(col_wv, col_ci, col_decomp, col_fit), 
+               cex = 1, pt.cex = c(1.25, 3, rep(1, m), 1.35), bty = "n")
+      }else{
+        legend(x = legend_position[1], y = legend_position[2],
+               legend = c(as.expression(bquote(paste(.(wv_title_part1), hat(nu)^2))),
+                          as.expression(bquote(paste("CI(",hat(nu)^2,", ",.(CI_conf),")"))),
+                          "Model-based WV"),
+               pch = c(16, 15, 1), 
+               lty = c(1, NA, 1), 
+               col = c(col_wv, col_ci, col_fit), 
+               cex = 1, pt.cex = c(1.25, 3, 1.35), bty = "n")
+      }
+      
+    }else{
+      if (legend_position == "topright"){
+        legend_position = 10^c(0.7*win_dim[2], 0.98*(win_dim[4] - 0.09*(win_dim[4] - win_dim[3])))
+        if (decomp == TRUE){
+          legend(x = legend_position[1], y = legend_position[2],
+                 legend = c(as.expression(bquote(paste(.(wv_title_part1), hat(nu)^2))),
+                            as.expression(bquote(paste("CI(",hat(nu)^2,", ",.(CI_conf),")"))),
+                            x$model$desc, "Model-based WV"),
+                 pch = c(16, 15, rep(NA, m), 1), 
+                 lty = c(1, NA, rep(1, m), 1), 
+                 col = c(col_wv, col_ci, col_decomp, col_fit), 
+                 cex = 1, pt.cex = c(1.25, 3, rep(1, m), 1.35), bty = "n")
+        }else{
+          legend(x = legend_position[1], y = legend_position[2],
+                 legend = c(as.expression(bquote(paste(.(wv_title_part1), hat(nu)^2))),
+                            as.expression(bquote(paste("CI(",hat(nu)^2,", ",.(CI_conf),")"))),
+                            "Model-based WV"),
+                 pch = c(16, 15, 1), 
+                 lty = c(1, NA, 1), 
+                 col = c(col_wv, col_ci, col_fit), cex = 1, pt.cex = c(1.25, 3, 1.35), bty = "n")
+        }
+      }else{
+        if (decomp == TRUE){
+          legend(x = legend_position[1], y = legend_position[2],
+                 legend = c(as.expression(bquote(paste(.(wv_title_part1), hat(nu)^2))),
+                            as.expression(bquote(paste("CI(",hat(nu)^2,", ",.(CI_conf),")"))),
+                            x$model$desc, "Model-based WV"),
+                 pch = c(16, 15, rep(NA, m), 1), 
+                 lty = c(1, NA, rep(1, m), 1), 
+                 col = c(col_wv, col_ci, col_decomp, col_fit), 
+                 cex = 1, pt.cex = c(1.25, 3, rep(1, m), 1.35), bty = "n")
+        }else{
+          legend(x = legend_position[1], y = legend_position[2],
+                 legend = c(as.expression(bquote(paste(.(wv_title_part1), hat(nu)^2))),
+                            as.expression(bquote(paste("CI(",hat(nu)^2,", ",.(CI_conf),")"))),
+                            "Model-based WV"),
+                 pch = c(16, 15, 1), 
+                 lty = c(1, NA, 1), 
+                 col = c(col_wv, col_ci, col_fit), cex = 1, pt.cex = c(1.25, 3, 1.35), bty = "n")
+        }
+      }
+    }
+  }
+}
