@@ -63,7 +63,10 @@ plot_pred = function(x, model, n.ahead, level = NULL,
   if (is.null(name_ts)){ name_ts = "Observation and Prediction" }
   
   if (!is.null(unit_time)){
-    if (class(unit_time) == "name" || class(unit_time) == "call"){
+    
+    
+    
+    if (inherits(unit_time, "name") || inherits(unit_time, "call")){
       name_time = comb(name_time, " (", unit_time, ")")
     }else{
       name_time = paste(name_time, " (", unit_time, ")", sep = "")
@@ -71,7 +74,11 @@ plot_pred = function(x, model, n.ahead, level = NULL,
   }
   
   if (!is.null(unit_ts)){
-    if (class(unit_ts) == "name" || class(unit_ts) == "call"){
+    
+   
+    
+    
+    if ( inherits(unit_ts, "name") ||  inherits(unit_ts, "call")){
       name_ts = comb(name_ts, " (", unit_ts, ")")
     }else{
       name_ts = paste(name_ts, " (", unit_ts, ")", sep = "")
@@ -250,7 +257,11 @@ plot_pred_gmwm = function(x, model, n.ahead, level = NULL,
   if (is.null(name_ts)){ name_ts = "Observation and Prediction" }
   
   if (!is.null(unit_time)){
-    if (class(unit_time) == "name" || class(unit_time) == "call"){
+    
+   
+    
+    
+    if ( inherits(unit_time, "name") ||  inherits(unit_time, "call")){
       name_time = comb(name_time, " (", unit_time, ")")
     }else{
       name_time = paste(name_time, " (", unit_time, ")", sep = "")
@@ -258,7 +269,9 @@ plot_pred_gmwm = function(x, model, n.ahead, level = NULL,
   }
   
   if (!is.null(unit_ts)){
-    if (class(unit_ts) == "name" || class(unit_ts) == "call"){
+    
+    
+    if ( inherits(unit_ts, "name") || inherits(unit_ts, "call") ){
       name_ts = comb(name_ts, " (", unit_ts, ")")
     }else{
       name_ts = paste(name_ts, " (", unit_ts, ")", sep = "")
